/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd;

/**
 * This exception is thrown if an error condition is detected
 * by PolyD during the creation of a new dispatcher.<p>
 * If a policy throws a <code>PolicyException</code> during
 * construction, the exception will NOT be intercepted by PolyD,
 * and you will have to catch it yourself (if you want to).
 * @see PolicyException
 * @version $Revision: 1.5 $, $Date: 2005/04/02 05:51:32 $
 * @author Antonio Cunei
 *
 */
public class DispatcherCreationException extends PolyDException {
 /**
  * The internal code of this exception. For information and debugging only.
  */
 final public int trouble;
 DispatcherCreationException(int trouble) {
  this.trouble=trouble;
 }
 DispatcherCreationException(int trouble,String s) {
  super(s);
  this.trouble=trouble;
 }
 /**
  * A textual representation of this error condition.
  */
 public String toString() {
  String s=Integer.toHexString(trouble).toUpperCase();
  int l=s.length();
  if (l>4) l=8; else l=4;
  for (; s.length() < l; s = "0" + s);
  return "ovm.polyd.DispatcherCreationException\n\n"+getMessage()+"\nTrouble #"+s+"\n";
 }
}
