/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd;

/**
 * Used to create manually new instances of the desired dispatcher.
 * Use a <code>Factory</code> to build dispatchers manually,
 * rather than using annotations.
 * <p>
 * This class is not normally accessed directly, and it is of use
 * only when using the pre-5.0
 * version of PolyD. To create a dispatcher manually, first create
 * a <code>Descriptor</code> to specify all the characteristics
 * of the desired dispatcher. When the <code>Descriptor</code>
 * is registered, a <code>Factory</code> is generated, that can
 * then be used to produce new dispatchers.<p>
 * The bodies must be equal, in number and class, to the list
 * supplied when building the <code>Descriptor</code>.
 * 
 * @author Antonio Cunei
 * @version $Revision: 1.6 $, $Date: 2005/04/03 02:49:23 $
 * @see Descriptor
 */
public abstract class Factory {
 Factory() {}
 
private void err() {
 throw new DispatcherCreationException(0x401,   
  "A dispatching Factory is being used with the wrong\n"+
  "number of arguments."
 );
}

/**
 * If you have only one body, use this method to create the
 * new dispatcher.
 * @param a the body
 * @return the new dispatcher, which can be downcasted to
 * the interface used to build the <code>Descriptor</code>.
 */
public Object getDispatcher1(Object a) {
 err();
 return null;
}

/**
 * If you have two bodies, use this method to create the
 * new dispatcher.
 * @param a the first body
 * @param b the second body
 * @return the new dispatcher, which can be downcasted to
 * the interface used to build the <code>Descriptor</code>.
 */
public Object getDispatcher2(Object a,Object b) {
 err();
 return null;
}

/**
 * If you have three bodies, use this method to create the
 * new dispatcher.
 * @param a the first body
 * @param b the second body
 * @param c the third body
 * @return the new dispatcher, which can be downcasted to
 * the interface used to build the <code>Descriptor</code>.
 */
public Object getDispatcher3(Object a,Object b,Object c) {
 err();
 return null;
}

/**
 * If you have four bodies, use this method to create the
 * new dispatcher.
 * @param a the first body
 * @param b the second body
 * @param c the third body
 * @param d the fourth body
 * @return the new dispatcher, which can be downcasted to
 * the interface used to build the <code>Descriptor</code>.
 */
public Object getDispatcher4(Object a,Object b,Object c,Object d) {
 err();
 return null;
}

/**
 * If you have more than four bodies, use this method to create the
 * new dispatcher.
 * @param a the array of bodies
 * @return the new dispatcher, which can be downcasted to
 * the interface used to build the <code>Descriptor</code>.
 */
public Object getDispatcherN(Object[] a) {
 err();
 return null;
}

}

