/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd;

/**
 * This error is thrown if an unexpected internal error
 * is detected during the execution of PolyD.<p>
 * This error should never occur. If it does, please
 * report the problem to us so that we can address the problem.
 * Please consult the PolyD homepage at
 * <a href="http://www.ovmj.org/polyd">http://www.ovmj.org/polyd</A>
 * for details.
 * @see PolyDException
 * @version $Revision: 1.2 $, $Date: 2005/04/02 05:51:32 $
 * @author Antonio Cunei
 *
 */
public class InternalError extends Error {
 /**
  * The internal code of this error. For information and debugging only.
  */
 final public int guru;
 InternalError(int guru) {
  this.guru=guru;
 }
 InternalError(int guru,String s) {
  super(s);
  this.guru=guru;
 }
/*#ifdef14
#else14 */
 InternalError(int guru,String s,Throwable t) {
  super(s,t);
  this.guru=guru;
 }
//#endif14
 /**
  * A textual representation of this error condition.
  */
 public String toString() {
  String s=Integer.toHexString(guru).toUpperCase();
  int l=s.length();
  if (l>4) l=8; else l=4;
  for (; s.length() < l; s = "0" + s);
  return "ovm.polyd.InternalError\n\n"+getMessage()+"\nGuru Meditation #"+s+
  "\n\nPlease report this error message to polyd @ ovmj.org.\n";
 }
}
