/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd;

/**
 * This exception should be thrown by the policy if an inconsistent
 * set of methods is detected (duplicate methods, for instance, or
 * ambiguities).<p>
 * This exception should <i>not</i> be thrown when the policy
 * finds at runtime that a message has no corresponding method:
 * see {@link MissingMethodException} for the appropriate action.
 * This exception is instead the appropriate response when an ambiguity
 * or a similar inconsistency is detected, either statically or dynamically.
 * 
 * @see MissingMethodException
 * @version $Revision: 1.1 $, $Date: 2005/04/02 06:02:09 $
 * @author Antonio Cunei
 *
 */
public class PolicyException extends PolyDException {
 /**
  * Constructs a new exception with the specified detail message.
  * @param message the detail message
  */
 public PolicyException(String message) {super(message);}
 /**
  * Constructs a new exception with <code>null</code> as its detail message.
  */
 public PolicyException() {super();}

// Note: Chainable exceptions are available as of 1.4. I am
// using the macro "ifdef14" to really mean "ifnot15", though.

/*#ifdef14
#else14 */
 /**
  * Constructs a new exception with the specified cause and a
  * detail message of <code>(cause==null ? null : cause.toString())</code>.
  * @param cause the cause
  */
 public PolicyException(Throwable cause) {super(cause);}
 /**
  * Constructs a new exception with the specified detail message and cause.
  * @param message the detain message
  * @param cause the cause
  */
 public PolicyException(String message,Throwable cause) {super(message,cause);}
//#endif14
 }
