/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd.policy;

/**
 * An invocation policy that prints on the standard output
 * all the method invocations, and the return values.
 * 
 * @version $Revision: 1.5 $, $Date: 2005/04/03 02:49:23 $
 * @author Antonio Cunei
 *
 */
public class DebuggingInvocation extends PlainInvocation {
 protected DebuggingInvocation() {}
 private static final Invocation theInvocation=new DebuggingInvocation();
 /**
  * Returns an instance of this invocation policy.
  * 
  * @return an instance of this policy (a singleton)
  */
 public static Invocation theInvocation() { return theInvocation; }

 
 public Object invoke(Object obj,java.lang.reflect.Method m,Object[] args) throws
  Throwable {
  
  System.out.println("> Entering " + m.toString());
  System.out.print("    with arguments [");
  for (int i = 0; i < args.length; i++) { // no Arrays.toString in pre-5.0
   if (i != 0)
    System.out.println(",");
   System.out.println(args[i]);
  }
  System.out.print("]");
  Object result = super.invoke(obj, m, args);
  System.out.println("< Exiting " + m.toString());
  if (result != null)
   System.out.println("    returning " + result.toString());
  return result;

 }
}
