/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd.policy;

/**
 * The common superclass of all invocation policies.
 * <p>
 * The methods defined in this class can be
 * overridden in order to create user-defined invocation policies.
 * Please check out the invidual methods below
 * to know more.
 * 
 * @version $Revision: 1.4 $, $Date: 2005/04/02 05:51:32 $
 * @author Antonio Cunei
 *
 */
abstract public class Invocation {

 /**
  * Returns an instance of this invocation policy.<p>
  * This method must be defined in every user-defined
  * invocation policy. It must return one instance of the
  * same class, normally a singleton allocated during construction.
  * This method is used reflexively to allow access to the
  * fields and methods of the class given the class name.
  * 
  * @return an instance of this class (a singleton)
  */
 public static Invocation theInvocation() { return null; }
 
 /**
  * Invoke one method, using the given argument, performing
  * additional actions whenever necessary.
  * 
  * @param obj the instance to which the message is sent
  * @param m the method
  * @param args the arguments (including wrapped primitives)
  * @return the result of the method invocation, or <code>null</code>
  * @throws Throwable
  */
 public Object invoke(Object obj,java.lang.reflect.Method m,Object[] args) throws
  Throwable {
  return null;
 }

 // empty constructor
 protected Invocation() {}
}
