/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd.tags;

import java.lang.annotation.*;
import ovm.polyd.Missing;

/**
 * Use this tag to specify the handling of messages
 * that do not have any corresponding methods
 * according to the current dispatching policy.<p>
 * change the interpretation of a message
 * or method name.<p>
 * If you specify this tag both for the whole interface and
 * for one specific method, the local selection overrides
 * the global choice. If no tag is specified, the dispatching
 * policy will decide what to do.
 * 
 * @see Missing
 * @author Antonio Cunei
 * @version $Revision: 1.4 $, $Date: 2005/04/02 05:51:32 $
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.TYPE,ElementType.METHOD})
public @interface OnMissing {
	/**
  * The way in which missing methods should be handled for this
  * interface, or prototype.
	 */
 Missing value(); // default Missing.STANDARD
}
