/*
  (c) 2005 Antonio Cunei, All rights reserved.

  This file is part of PolyD.

  PolyD is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  PolyD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with PolyD; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package ovm.polyd.tags;

import java.lang.annotation.*;

/**
 * This tag is used to pre-initialize the dispatching cache
 * at dispatcher-building time (and to perform
 * early consistency checks).<p>
 * It specifies an array of combinations of classes,
 * each of which will be passed on to the dispatching
 * policy to "peek" in advance which method would be
 * called with arguments of those classes, and to
 * check whether one exists and whether there are
 * any ambiguities.<p>
 * Note that, due to limitations in the structure of
 * Java annotations, this tag cannot be used to preload
 * arbitrary raw arguments (except for classes). If that
 * is required, consider building the descriptor manually
 * instead, using a <code>Descriptor</code>.
 * @see Seq
 * @see ovm.polyd.Descriptor
 * @author Antonio Cunei
 * @version $Revision: 1.3 $, $Date: 2005/04/02 05:51:32 $
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD})
public @interface Preload {
 /**
  * The combinations that should be preloaded.
  */
	Seq[] value();
}
